@@ -7,8 +7,11 @@ from wildebeest.path_funcs import join_outdir_filename_extension
 TEST_DIR = Path(__file__).parent
 SAMPLE_DATA_DIR = Path(TEST_DIR) / 'sample_data'
 TEMP_DATA_DIR = SAMPLE_DATA_DIR / 'tmp'
-IMAGE_FILENAMES = ['2RsJ8EQ', '2TqoToT', '2VocS58', '2scKPIp', '2TsO6Pc', '2SCv0q7']
-IMAGE_URLS = [f'https://bit.ly/{filename}' for filename in IMAGE_FILENAMES]
+IMAGE_FILENAMES = [f'wildebeest_big{num}.jpg' for num in range(1, 7)]
+IMAGE_URLS = [
+    f'https://raw.githubusercontent.com/ShopRunner/wildebeest/master/tests/sample_data/{filename}'
+    for filename in IMAGE_FILENAMES
+]
 
 from tests.fixtures import *
 
